
From: David Brownell <david-b@pacbell.net>

This patch turns a user mode driver error into a hard error, and updates
the relevant diagnostic slightly to help troubleshooting.

This had been left as a soft error to give various user mode drivers a
change to be properly fixed, with the statement that starting in about
2.6.10 it would be changed.  It had been mostly safe as a soft error ... 
but that can not be guaranteed.  Now that a year has passed, it's time to
really insist that the user mode drivers finally fix their relevant bugs.

Signed-off-by: David Brownell <dbrownell@users.sourceforge.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/usb/core/devio.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff -puN drivers/usb/core/devio.c~usb-turn-a-user-mode-driver-error-into-a-hard-error drivers/usb/core/devio.c
--- 25/drivers/usb/core/devio.c~usb-turn-a-user-mode-driver-error-into-a-hard-error	Mon Apr  4 15:28:38 2005
+++ 25-akpm/drivers/usb/core/devio.c	Mon Apr  4 15:28:38 2005
@@ -786,16 +786,16 @@ static int proc_setconfig(struct dev_sta
  		for (i = 0; i < actconfig->desc.bNumInterfaces; ++i) {
  			if (usb_interface_claimed(actconfig->interface[i])) {
 				dev_warn (&ps->dev->dev,
-					"usbfs: interface %d claimed "
+					"usbfs: interface %d claimed by %s "
 					"while '%s' sets config #%d\n",
 					actconfig->interface[i]
 						->cur_altsetting
 						->desc.bInterfaceNumber,
+					actconfig->interface[i]
+						->dev.driver->name,
 					current->comm, u);
-#if 0	/* FIXME:  enable in 2.6.10 or so */
  				status = -EBUSY;
 				break;
-#endif
 			}
  		}
  	}
_
